=========================
Welcome to lazr.delegates
=========================

Contents:

.. toctree::
   :maxdepth: 2

   lazr/delegates/docs/usage
   lazr/delegates/docs/NEWS
   HACKING



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
